availableModels: 'availableModels()' If the API key is valid in the system,...

View source: R/patientChat_naive.R

availableModelsR Documentation

availableModels() If the API key is valid in the system, returns available models to the user from the LLM provider.

Description

OpenAI is the only one currently supported.

Usage

availableModels()

Value

A string list with the id of a vailable models.


PatientGenerator documentation built on Sept. 16, 2026, 1:06 a.m.