| conceptSearchModule | R Documentation |
Reusable UI and server for searching the vocabulary (Hecate) and selecting a concept. Shows a button that opens a modal with text input, search button, and results in a DT table. Optional callback when a concept is selected.
conceptSearchUI(id, buttonLabel = "Concept search")
conceptSearchServer(id, onConceptSelected = NULL, placeholderText = "")
id |
Module namespace id. |
buttonLabel |
Label for the trigger button (default |
onConceptSelected |
Optional function of one argument |
placeholderText |
Character string used as placeholder text in the search input field. |
conceptSearchUI(): UI for the concept search: a single button that opens the search modal.
conceptSearchServer(): Server for the concept search modal (text input, search, DT, close).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.