View source: R/patientChat_naive.R
| availableModels | R Documentation |
availableModels() If the API key is valid in the system, returns available models to the user from the LLM provider.OpenAI is the only one currently supported.
availableModels()
A string list with the id of a vailable models.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.